# Generated by Django 4.2 on 2023-09-12 12:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_drf_otp', '0004_alter_usernotificationpreference_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='verificationtoken',
            name='secret_chars',
            field=models.CharField(max_length=64, null=True, verbose_name='Extra secret characters'),
        ),
        migrations.AlterField(
            model_name='usernotificationpreference',
            name='notification_type',
            field=models.CharField(
                choices=[('email', 'Email'), ('sms', 'Sms'), ('authenticator', 'Authenticator')],
                default='email',
                max_length=32,
                verbose_name='Notification Type',
            ),
        ),
        migrations.AlterField(
            model_name='verificationtoken',
            name='token_type',
            field=models.CharField(
                choices=[('totp', 'Totp'), ('hotp', 'Hotp')], default='totp', max_length=100, verbose_name='Token type'
            ),
        ),
    ]
